function statespace = fillStateSpace(node)

%FILLSTATESPACE   Returns the state space transition matrix of NODE
%   FILLSTATESPACE(NODE) returns the connectivity matrix describing all of
%   the state transitions within the network. This matrix will be of size
%   2^N*2^N, where N is the number of nodes in NODE.
%   A normal matrix is currently used, whereas this *should* use a sparse
%   matrix.

%	 Kai Willadsen 5/7/03

nodeUpdated = resetNodeStats(node);
statespace = zeros (2 ^ length(node), 2 ^ length(node));

% evolve network
for i=0:(length(statespace)-1)
    binstr = dec2bin(i, length(node));
    
    for j=1:length(nodeUpdated)
        nodeUpdated(j).state = str2num(binstr(j));
    end
        
    nodeUpdated = setLUTLines(nodeUpdated);        
    nodeUpdated = setNodeNextState(nodeUpdated);
    
    
    for j=1:length(nodeUpdated)
        nodeUpdated(j).state = nodeUpdated(j).nextState;
    end
    
    nextState = polyval (getStateVector(nodeUpdated), 2);
    
    statespace (i+1, (nextState+1)) = 1;   
end
