function writeStateSpaceToPajek(mat,file)

%WRITESTATESPACETOPAJEK   Converts a Matlab RBN state space matrix into a Pajek input file.
%   WRITESTATESPACETOPAJEK(MAT,'file_name') writes the network described by the 
%   (sparse) square matrix MAT to a Pajek input file called 'file_name.net' 
%   The network will be weighted and directed and vertices will be labelled 
%	with a binary string.
%
%   For example,
%	
%      writeStateSpaceToPajek(W,'Network1')
%
%   creates a file called 'Network1.net' in the present working 
%   directory from the network descibed by W.

%	 Ben Skellett, 27/07/03

if size(mat,1)~=size(mat,2)
   error('Matrix is not square');
end

if ~ischar(file)
   error('Specify file name as a string');
end

vertices=1:size(mat,1); 
labels=dec2bin(vertices-1);
labels=cellstr(labels);

[i,j,v]=find(mat); 

arcs=[i'; j'; v'];

fid=fopen([file,'.net'],'w');
fprintf(fid,'*Vertices %g \r',size(mat,1));
for u=1:size(mat,1)
   fprintf(fid,'%g  ', vertices(u));
   fprintf(fid,'"%s" \r', labels{u});
end
fprintf(fid,'*Arcs \r');
fprintf(fid,'%g  %g  %g\r',arcs);
fclose(fid);
